IndicatorData class
Data model for an active indicator
Constructors
- IndicatorData({required IndicatorType type, Offset? position, Offset? endPosition, Duration? duration, Rect? bounds, String? message, CharacterAction? action, DateTime? timestamp})
Properties
- action → CharacterAction?
-
final
- bounds → Rect?
-
final
- duration → Duration?
-
final
- endPosition → Offset?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
final
- position → Offset?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- type → IndicatorType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited